@@ -79,6 +79,30 @@ class Node:
             raise RuntimeError
 
 
+    def unrolled(self) -> Iterator['Node']:
+        """
+        Returns an iterator that provides unrolled nodes for this instance
+
+        Yields
+        ------
+        :class:`~Node`
+            Unrolled array dimensions
+
+        .. versionadded:: 1.20.0
+        """
+        cls = type(self)
+        if isinstance(self, AddressableNode) and self.is_array: # pylint: disable=no-member
+            # Is an array. Yield a Node object for each instance
+            range_list = [range(n) for n in self.array_dimensions] # pylint: disable=no-member
+            for idxs in itertools.product(*range_list):
+                N = cls(self.inst, self.env, self.parent)
+                N.current_idx = idxs # type: ignore
+                yield N
+        else:
+            # not an array. Nothing to unroll
+            yield cls(self.inst, self.env, self.parent)
+
+
     def children(self, unroll: bool=False, skip_not_present: bool=True) -> Iterator['Node']:
         """
         Returns an iterator that provides nodes for all immediate children of
@@ -1072,6 +1096,54 @@ class FieldNode(VectorNode):
 
         return False
 
+    @property
+    def is_up_counter(self) -> bool:
+        """
+        Denotes whether this field is a counter and the property assignments imply
+        it has up-counting functionality.
+
+        .. versionadded:: 1.21
+        """
+        if not self.get_property('counter'):
+            # Not a counter!
+            return False
+
+        for prop_name in self.list_properties():
+            if (
+                prop_name.startswith("incr")
+                or (prop_name == "overflow")
+                or (prop_name == "saturate")
+                or (prop_name == "threshold")
+            ):
+                return True
+
+        # No up-counter properties were set
+        if self.is_down_counter:
+            # Is explicitly a down-counter, so not an up-counter
+            return False
+
+        # No up/down properties were set. Assume up-counter
+        return True
+
+
+    @property
+    def is_down_counter(self) -> bool:
+        """
+        Denotes whether this field is a counter and the property assignments imply
+        it has down-counting functionality.
+
+        .. versionadded:: 1.21
+        """
+        if not self.get_property('counter'):
+            # Not a counter!
+            return False
+
+        for prop_name in self.list_properties():
+            if prop_name.startswith("decr") or (prop_name == "underflow"):
+                return True
+
+        return False
+
 #===============================================================================
 class RegNode(AddressableNode):
 
@@ -1153,6 +1225,30 @@ class MemNode(AddressableNode):
         num_entries = self.get_property('mementries')
         return entry_size * num_entries
 
+    @property
+    def is_sw_writable(self) -> bool:
+        """
+        Memory is writable by software
+
+        .. versionadded:: 1.21
+        """
+        sw = self.get_property('sw')
+
+        return sw in (rdltypes.AccessType.rw, rdltypes.AccessType.rw1,
+                        rdltypes.AccessType.w, rdltypes.AccessType.w1)
+
+    @property
+    def is_sw_readable(self) -> bool:
+        """
+        Memory is readable by software
+
+        .. versionadded:: 1.21
+        """
+        sw = self.get_property('sw')
+
+        return sw in (rdltypes.AccessType.rw, rdltypes.AccessType.rw1,
+                        rdltypes.AccessType.r)
+
 #===============================================================================
 def get_group_node_size(node: Union[AddrmapNode, RegfileNode]) -> int:
     """
