@@ -278,7 +278,7 @@ class UserEnum(enum.Enum):
 
 
     def __int__(self) -> int:
-        return self.value # type: ignore
+        return self.value
 
     def __bool__(self) -> bool:
         return bool(self.value)
@@ -551,6 +551,26 @@ class PropertyReference:
         #: property is being referenced.
         self.node = None # type: Node
 
+    def __repr__(self) -> str:
+        return "<%s %s->%s at 0x%x>" % (
+            self.__class__.__qualname__,
+            self.node.get_path(),
+            self.name,
+            id(self)
+        )
+
+    def __eq__(self, other: object) -> bool:
+        """
+        Property reference equality checks determine whether the other object
+        represents the same reference (node represents the same position in the
+        register model's hierarchy and the property referenced is the same)
+        """
+        if not isinstance(other, PropertyReference):
+            return NotImplemented
+        if self.name != other.name:
+            return False
+        return self.node.get_path() == other.node.get_path()
+
     @property
     def name(self) -> str:
         """
@@ -568,6 +588,18 @@ class PropertyReference:
     def _validate(self) -> None:
         pass
 
+    @property
+    def width(self) -> Optional[int]:
+        """
+        Get the equivalent width of the property reference.
+
+        Returns None if reference doesn't have a specifically defined width
+
+        .. versionadded:: 1.21
+        """
+        raise NotImplementedError
+
+
 #===============================================================================
 class ArrayPlaceholder():
     """
